/// <reference types="node" />
/// <reference types="express" />
import * as express from 'express';
import { CtorT, ControllerT, StaticModelT, ModelT, PkType, ServiceT, PolicyDescriptor } from '../../core';
export declare type DatabaseMetadata = {
    name: string;
    user: string;
    password: string;
    host: string | {
        domain: string;
        port: number;
    };
    dialect?: string;
};
export declare type OrmMetadata = {
    enabled?: boolean;
    db?: DatabaseMetadata;
};
export declare type JwtMetadata = {
    secret: string | Buffer;
    tokenProperty?: string;
};
export declare type ServerMetadata = {
    port: number | string;
    orm?: OrmMetadata;
    jwt?: JwtMetadata;
    path?: string;
    controllers?: CtorT<ControllerT>[];
    models?: StaticModelT<ModelT<PkType>>[];
    services?: CtorT<ServiceT>[];
    policies?: PolicyDescriptor[];
    middleware?: express.Handler[];
    allowCrossOrigin?: boolean;
};
